summaryrefslogtreecommitdiffstats
path: root/kregexpeditor/textwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kregexpeditor/textwidget.cpp')
-rw-r--r--kregexpeditor/textwidget.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kregexpeditor/textwidget.cpp b/kregexpeditor/textwidget.cpp
index 99a77e1..d2f7549 100644
--- a/kregexpeditor/textwidget.cpp
+++ b/kregexpeditor/textwidget.cpp
@@ -22,7 +22,7 @@
#include "textwidget.h"
#include "textregexp.h"
#include "selectablelineedit.h"
-#include <tqlayout.h>
+#include <layout.h>
TextWidget::TextWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
@@ -56,19 +56,19 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
// I need to force the parent to tqrepaint, as the size change of this
// widget may not be enough for the parent to change size, and in that
// case the parent would not tqrepaint, and the text widget would not be
// resized.
TQWidget *p = TQT_TQWIDGET(parent());
if (p)
- p->tqrepaint();
+ p->repaint();
_editorWindow->updateContent( this );
}
-TQSize TextWidget::tqsizeHint() const
+TQSize TextWidget::sizeHint() const
{
- return _edit->tqsizeHint();
+ return _edit->sizeHint();
}
void TextWidget::paintEvent( TQPaintEvent *e)
@@ -56,19 +56,19 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
- // I need to force the parent to tqrepaint, as the size change of this
+ // I need to force the parent to repaint, as the size change of this
// widget may not be enough for the parent to change size, and in that
@@ -56,19 +56,19 @@ void TextWidget::init( const TQString& txt )
// widget may not be enough for the parent to change size, and in that
- // case the parent would not tqrepaint, and the text widget would not be
+ // case the parent would not repaint, and the text widget would not be
// resized.
TQWidget *p = TQT_TQWIDGET(parent());